
# Class: subclass test




URI: [ks:SubclassTest](https://w3id.org/linkml/tests/kitchen_sink/SubclassTest)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[ClassWithSpaces]<slot%20with%20space%202%200..1-++[SubclassTest&#124;slot_with_space_1(i):string%20%3F],[ClassWithSpaces]^-[SubclassTest],[ClassWithSpaces])](https://yuml.me/diagram/nofunky;dir:TB/class/[ClassWithSpaces]<slot%20with%20space%202%200..1-++[SubclassTest&#124;slot_with_space_1(i):string%20%3F],[ClassWithSpaces]^-[SubclassTest],[ClassWithSpaces])

## Parents

 *  is_a: [ClassWithSpaces](ClassWithSpaces.md)

## Attributes


### Own

 * [➞slot with space 2](subclassTest__slot_with_space_2.md)  <sub>0..1</sub>
     * Range: [ClassWithSpaces](ClassWithSpaces.md)

### Inherited from class with spaces:

 * [➞slot with space 1](classWithSpaces__slot_with_space_1.md)  <sub>0..1</sub>
     * Range: [String](types/String.md)
